pub struct Options {
pub include_only_targeted_user_lists: Option<bool>,
pub path_query_options: Option<PathQueryOptions>,
}Expand description
Additional query options.
This type is not used in any activity, and only used as part of another schema.
Fields
include_only_targeted_user_lists: Option<bool>Set to true and filter your report by FILTER_INSERTION_ORDER or FILTER_LINE_ITEM to include data for audience lists specifically targeted by those items.
path_query_options: Option<PathQueryOptions>Options that contain Path Filters and Custom Channel Groupings.