PathFilter

Struct PathFilter 

pub struct PathFilter {
    pub event_filters: Option<Vec<EventFilter>>,
    pub path_match_position: Option<String>,
}
Path filters specify which paths to include in a report. A path is the result of combining DV360 events based on User ID to create a workflow of users’ actions. When a path filter is set, the resulting report will only include paths that match the specified event at the specified position. All other paths will be excluded.

This type is not used in any activity, and only used as part of another schema.

Fields

event_filters: Option<Vec<EventFilter>>

Filter on an event to be applied to some part of the path.

path_match_position: Option<String>

Indicates the position of the path the filter should match to (first, last, or any event in path).